@@ -11,11 +11,16 @@ from .entry import CacheEntry
 
 class RedisStore(object):
     """Caching implementation that uses Redis as data storage."""
-    def __init__(self, host='localhost', port=6379, db=0):
+
+    DEFAULT_TTL = 5 * 60  # seconds
+
+    def __init__(self, host='localhost', port=6379, db=0,
+            ttl=DEFAULT_TTL):
+        self.ttl = ttl
         try:
             from redis import Redis
         except ImportError:
-            raise RuntimeError('Redis support is not available')
+            raise RuntimeError('Redis support is not available. Run "pip install redis".')
 
         self.redis = Redis(host=host, port=port, db=db)
 
@@ -29,7 +34,7 @@ class RedisStore(object):
 
     def __setitem__(self, key, entry):
         data = dumps(entry.to_dict()).encode('utf-8')
-        self.redis.set(key, data)
+        self.redis.setex(key, data, self.ttl)
 
     def __delitem__(self, key):
         self.redis.delete(key)
