@@ -4,6 +4,7 @@
 from .base import (
     CollectionResource,
     DeleteMixin,
+    DictMixin,
     Resource,
     SaveMixin,
     StatusMixin,
@@ -12,7 +13,7 @@ from .login_attempt import LoginAttemptList
 from .password_reset_token import PasswordResetTokenList
 
 
-class Application(Resource, DeleteMixin, SaveMixin, StatusMixin):
+class Application(Resource, DeleteMixin, DictMixin, SaveMixin, StatusMixin):
     """Stormpath Application resource.
 
     More info in documentation:
